greenstalk
==========

A Python client for beanstalkd: the simple, fast work queue.

.. image:: https://secure.travis-ci.org/mayhewj/greenstalk.png?branch=master
        :target: https://travis-ci.org/mayhewj/greenstalk
